@@ -146,20 +146,19 @@ int main( int argc, char **argv )
         int end_pos = line_offsets[bi.end_line - 1] + bi.end_col - 1;
 
         QString xml = xml_text.mid(start_pos, end_pos - start_pos);
-        int index = 0;
+        int positionOfCommentStart = 0;
         while (true) {
-            index = xml.indexOf("<!--");
-            if (index == -1)
+            positionOfCommentStart = xml.indexOf("<!--");
+            if (positionOfCommentStart == -1)
                 break;
-            int end_index = index + 4;
+            int end_index = positionOfCommentStart + 4;
             while (xml.at(end_index) != '>' ||
                    xml.at(end_index-1) != '-' ||
                    xml.at(end_index-2) != '-')
             {
                 end_index++;
             }
-            xml.remove(index, end_index + 1 - index);
-            index = end_index;
+            xml.remove(positionOfCommentStart, end_index + 1 - positionOfCommentStart);
         }
         StructureParser::descape(xml);
 
